@@ -36,6 +36,7 @@ import urllib2
 from datetime import datetime
 import mimetools, mimetypes, itertools
 import urllib
+from collections import OrderedDict
 
 try:
     from logging import NullHandler
@@ -315,6 +316,7 @@ class DexcellSender(object):
                 groups[key]['values'] = {}
                 groups[key]['values'][snid] = float(reading['value'])
             total_service = total_service + 1
+            OrderedDict(sorted(groups.items(), key=lambda t: t[0]))
         return groups.values(), total_service
 
     def __insertRawJSONData(self, data, maxerrorRetry,token):
